.. _models-link:

Models
******

.. toctree::
   :maxdepth: 1

   models/chung_everhart
   models/dionne
   models/sombrin
   models/vaughan

Todo Models
===========

.. toctree::
   :maxdepth: 1

   models/dekker
   models/dionne_3d
   models/furman_pivi
   models/okgm
   models/slab

.. todo::
   DRYer fit, look at Chung Everhart and Dionne in particular.
